==> qt-creator-opensource-src-4.0.1.zip: qt-creator-opensource-src-4.0.1/src/libs/modelinglib/qmt/diagram_ui/diagram_mime_types.h <==
/****************************************************************************
**
** Copyright (C) 2016 Jochen Becher
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef QMT_DIAGRAM_MIME_TYPES_H
#define QMT_DIAGRAM_MIME_TYPES_H

namespace qmt {

// mime types for drag&drop
static const char MIME_TYPE_MODEL_ELEMENTS[] = "text/model-elements";
static const char MIME_TYPE_NEW_MODEL_ELEMENTS[] = "text/new-model-elements";

// object type constants used within drag&drop
static const char ELEMENT_TYPE_PACKAGE[] = "package";
static const char ELEMENT_TYPE_COMPONENT[] = "component";
static const char ELEMENT_TYPE_CLASS[] = "class";
static const char ELEMENT_TYPE_ITEM[] = "item";
static const char ELEMENT_TYPE_ANNOTATION[] = "annotation";
static const char ELEMENT_TYPE_BOUNDARY[] = "boundary";

} // namespace qmt

#endif // QMT_DIAGRAM_MIME_TYPES_H

==> qt-creator-opensource-src-4.2.2.zip: qt-creator-opensource-src-4.2.2/src/libs/modelinglib/qmt/diagram_ui/diagram_mime_types.h <==
/****************************************************************************
**
** Copyright (C) 2016 Jochen Becher
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

namespace qmt {

// mime types for drag&drop
static const char MIME_TYPE_MODEL_ELEMENTS[] = "text/model-elements";
static const char MIME_TYPE_NEW_MODEL_ELEMENTS[] = "text/new-model-elements";

// object type constants used within drag&drop
static const char ELEMENT_TYPE_PACKAGE[] = "package";
static const char ELEMENT_TYPE_COMPONENT[] = "component";
static const char ELEMENT_TYPE_CLASS[] = "class";
static const char ELEMENT_TYPE_ITEM[] = "item";
static const char ELEMENT_TYPE_ANNOTATION[] = "annotation";
static const char ELEMENT_TYPE_BOUNDARY[] = "boundary";

} // namespace qmt
